@@ -1,8 +1,5 @@
 #pragma once
-
-#include <panda/std.h>
-#include <panda/perl.h>
-#include <panda/util.h>
+#include <xs/xs.h>
 #include <panda/time.h>
 #include <panda/date.h>
 
@@ -22,7 +19,7 @@
 #  define SvMUV(x) ((uint64_t)SvNV(x))
 #endif
 
-namespace panda { namespace xsdate {
+namespace xs { namespace date {
 
 using namespace panda::time;
 using namespace panda::date;
@@ -31,16 +28,16 @@ static const char* DATE_CLASS    = "Panda::Date";
 static const char* DATEREL_CLASS = "Panda::Date::Rel";
 static const char* DATEINT_CLASS = "Panda::Date::Int";
 
-inline tz* tzget_required (SV* zone) {
+inline const tz* tzget_required (SV* zone) {
     return (zone && SvOK(zone)) ? tzget(SvPV_nolen(zone)) : tzlocal();
 }
 
-inline tz* tzget_optional (SV* zone) {
+inline const tz* tzget_optional (SV* zone) {
     return zone ? (SvOK(zone) ? tzget(SvPV_nolen(zone)) : tzlocal()) : NULL;
 }
 
-inline void daterel_chkro (DateRel* THIS) {
-    if (THIS->isConst()) croak("Panda::Date::Rel: cannot change this object - it's read only");
+inline void daterel_chkro (const DateRel* THIS) {
+    if (THIS->is_const()) croak("Panda::Date::Rel: cannot change this object - it's read only");
 }
 
-};};
+}}
